package com.wd.workoffice.ui.activity.bat.work;

import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.alibaba.fastjson.JSON;
import com.wd.workoffice.R;
import com.wd.workoffice.app.BaseBean;
import com.wd.workoffice.app.WorkToolBarActivity;
import com.wd.workoffice.bean.TicketBean;
import com.wd.workoffice.bean.TicketDetailBean;
import com.wd.workoffice.retrofit.RtfUtils;
import com.wd.workoffice.retrofit.WorkObserver;
import com.wd.workoffice.ui.adapter.WorkFinancialTicketDetailAdapter;

import java.util.ArrayList;
import java.util.List;

import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import flexible.xd.android_base.network.rtfhttp.Transformer;
import io.reactivex.disposables.Disposable;

/**
 * 工作台 - 收票详情
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class WorkFinancialReceiveTicketDetailActivity extends WorkToolBarActivity {
    @BindView(R.id.tv_refuse)
    TextView tvRefuse;
    @BindView(R.id.tv_agree)
    TextView tvAgree;
    @BindView(R.id.ll_bottom)
    LinearLayout llBottom;
    @BindView(R.id.tv_client)
    TextView tvClient;
    @BindView(R.id.tv_price)
    TextView tvPrice;
    @BindView(R.id.tv_tax)
    TextView tvTax;
    @BindView(R.id.tv_remark)
    TextView tvRemark;
    @BindView(R.id.rv_data)
    RecyclerView rvData;
    @BindView(R.id.tv_desc)
    TextView tvDesc;
    private List<TicketDetailBean> dataList;
    private WorkFinancialTicketDetailAdapter dataAdapter;

    @Override
    protected void initView() {
        ButterKnife.bind(this);
        tvDesc.setText("所属供应商");
        rvData.setLayoutManager(new LinearLayoutManager(this, RecyclerView.VERTICAL, false));
    }

    @Override
    protected void initData() {
        TicketBean.RecordsBean info = JSON.parseObject(getIntent().getStringExtra("info"), TicketBean.RecordsBean.class);
        getData(info.getId() + "");
        tvClient.setText(info.getSupplierName());
        tvPrice.setText(String.valueOf(info.getInvoiceSum()));
        tvTax.setText(String.valueOf(info.getTax()));
        tvRemark.setText(info.getApplyRemark());
        if (TextUtils.equals(info.getStatus(), "0")) {
            llBottom.setVisibility(View.VISIBLE);
        } else {
            llBottom.setVisibility(View.GONE);
        }
        dataList = new ArrayList<>();
        dataAdapter = new WorkFinancialTicketDetailAdapter(R.layout.item_ticket_detail, dataList);
        dataAdapter.bindToRecyclerView(rvData);

    }

    private void getData(String id) {
        RtfUtils.getRtf().ticketReceiveDetail(id).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseBean>() {


            @Override
            public void doOnSubscribe(Disposable d) {
            }

            @Override
            public void onFail(String errorMsg) {
                hideLoading();
                toast(errorMsg);
            }

            @Override
            public void onSuccess(BaseBean data) {
                hideLoading();
                if (data.getCode() != 0) {
                    toast(data.getMessage());
                    return;
                }
                List<TicketDetailBean> dataBean = JSON.parseArray(data.getData().toString(), TicketDetailBean.class);
                dataList.addAll(dataBean);
                dataAdapter.notifyDataSetChanged();
            }
        });
    }

    @Override
    protected void initEvent() {
    }

    @Override
    protected int layoutId() {
        return R.layout.activity_work_financial_ticket_detail;
    }



    @OnClick({R.id.tv_refuse, R.id.tv_agree})
    public void onViewClicked(View view) {
        switch (view.getId()) {
            case R.id.tv_refuse:
                break;
            case R.id.tv_agree:
                break;
        }
    }
}
